Module font

Module font 

font datastructures and fonctions made from Font.cpp of SFML

Structs

CharInfo
CharInfo
Font
Contain a face and everything needed to render a glyph. The font have to be modified by the Text that old it so most of the time you will need to wrap it into MutResource.

Enums

TextError