pub struct SharedWindow { /* private fields */ }Expand description
Shared Window is a window that can be shared between thread.
Implementations
Sourcepub fn new(window: &mut Window) -> SharedWindow
pub fn new(window: &mut Window) -> SharedWindow
Examples found in repository?
examples/threads.rs (line 16)
13fn main() {
14 let mut window = Window::new(gust::WIDTH, gust::HEIGHT, "Hello");
15 let event_handler = EventHandler::new(&window);
16 let mut shared = SharedWindow::new(&mut window);
17 let (send, recv) = mpsc::channel();
18
19 let renderer = thread::spawn(move || {
20 render(&mut shared, recv);
21 });
22
23 window.poll(None);
24 while window.is_open() {
25 window.poll_events();
26
27 for event in event_handler.fetch() {
28 match event.1 {
29 pressed!(Escape) => window.close(),
30 _ => {}
31 }
32 }
33 }
34 send.send(()).ok().expect("Failed to send ()");
35
36 renderer.join().unwrap();
37}Sourcepub fn active(&mut self) -> bool
pub fn active(&mut self) -> bool
Examples found in repository?
examples/threads.rs (line 40)
39fn render(shared: &mut SharedWindow, recv: mpsc::Receiver<()>) {
40 shared.active();
41 let texture_rc =
42 Rc::new(Texture::from_path("examples/texture/Dirt.png").expect("Cannot open New.png"));
43 let sprite = Sprite::from(&texture_rc);
44
45 loop {
46 if recv.try_recv() == Ok(()) {
47 break;
48 }
49 shared.clear(Color::red());
50 shared.draw(&sprite);
51 shared.display();
52 }
53}Sourcepub fn display(&mut self)
pub fn display(&mut self)
Examples found in repository?
examples/threads.rs (line 51)
39fn render(shared: &mut SharedWindow, recv: mpsc::Receiver<()>) {
40 shared.active();
41 let texture_rc =
42 Rc::new(Texture::from_path("examples/texture/Dirt.png").expect("Cannot open New.png"));
43 let sprite = Sprite::from(&texture_rc);
44
45 loop {
46 if recv.try_recv() == Ok(()) {
47 break;
48 }
49 shared.clear(Color::red());
50 shared.draw(&sprite);
51 shared.display();
52 }
53}Sourcepub fn clear(&self, color: Color)
pub fn clear(&self, color: Color)
Examples found in repository?
examples/threads.rs (line 49)
39fn render(shared: &mut SharedWindow, recv: mpsc::Receiver<()>) {
40 shared.active();
41 let texture_rc =
42 Rc::new(Texture::from_path("examples/texture/Dirt.png").expect("Cannot open New.png"));
43 let sprite = Sprite::from(&texture_rc);
44
45 loop {
46 if recv.try_recv() == Ok(()) {
47 break;
48 }
49 shared.clear(Color::red());
50 shared.draw(&sprite);
51 shared.display();
52 }
53}Trait Implementations
Sourcefn draw<T: Drawable>(&mut self, drawable: &T)
fn draw<T: Drawable>(&mut self, drawable: &T)
Function that draw on itself needed by everything that can be draw.
fn projection(&self) -> &Matrix4<f32>
fn get_center(&self) -> Vector<f32>
fn get_sizes(&self) -> Vector<f32>
Sourcefn draw_with_context_mut<T: DrawableMut>(
&mut self,
drawable: &mut T,
context: &mut Context<'_>,
)
fn draw_with_context_mut<T: DrawableMut>( &mut self, drawable: &mut T, context: &mut Context<'_>, )
Draw with context fonction if you want to define you own fonction
Sourcefn draw_mut<T: DrawableMut>(&mut self, drawable: &mut T)
fn draw_mut<T: DrawableMut>(&mut self, drawable: &mut T)
Function that can draw a DrawableMut.