Coord

Type Alias Coord 

pub type Coord = Vector2<usize>;

Aliased Type

pub struct Coord {
    pub data: ArrayStorage<usize, U2, U1>,
    /* private fields */
}

Fields

data: ArrayStorage<usize, U2, U1>

The data storage that contains all the matrix components and informations about its number of rows and column (if needed).