Matrix4

Type Alias Matrix4 

pub type Matrix4<N> = Matrix<N, U4, U4, <DefaultAllocator as Allocator<N, U4, U4>>::Buffer>;
A stack-allocated, column-major, 4x4 square matrix.

Aliased Type

pub struct Matrix4<N> {
    pub data: <DefaultAllocator as Allocator<N, U4, U4>>::Buffer,
    /* private fields */
}

Fields

data: <DefaultAllocator as Allocator<N, U4, U4>>::Buffer

The data storage that contains all the matrix components and informations about its number of rows and column (if needed).