pub type Point<T> = Vector<T>;Aliased Type
pub struct Point<T> {
pub data: <DefaultAllocator as Allocator<T, U2>>::Buffer,
/* private fields */
}Fields
data: <DefaultAllocator as Allocator<T, U2>>::BufferThe data storage that contains all the matrix components and informations about its number of rows and column (if needed).