pub type Vector<T> = Vector2<T>;Aliased Type
pub struct Vector<T> {
pub data: <DefaultAllocator as Allocator<T, U2>>::Buffer,
/* private fields */
}Fields
data: <DefaultAllocator as Allocator<T, U2>>::BufferThe data storage that contains all the matrix components and informations about its number of rows and column (if needed).