Every traits needed by drawable object
Structs
- Context
- Context needed to handle a draw of a vertex array A context is needed by the drawer to handle the drawing process a default context can be use ether
- IDENTITY
Enums
- Blend
Mode - Blend mode needed to draw
Traits
- Drawable
- Trait that can be use to draw on window
- Drawable
Mut - Drawer
- Trait defining a drawer